@@ -27,23 +27,9 @@ def build(ctxt):
 @task
 def publish(ctxt, repository):
     """
-    Publish package and push to all remotes: --repository <pypi,gitlab>
+    Publish package and push to all remotes: --repository <>
     
-    The mandtory `--repository` option expects repositories to be configured in `~/.pypirc`:
-    
-        [distutils]
-        index-servers =
-            pypi
-            gitlab
-
-        [pypi]
-        username = __token__
-        password = pypi-<token>
-
-        [gitlab]
-        repository = https://gitlab.dev.beat.no/api/v4/projects/229/packages/pypi
-        username = __token__
-        password = <token>
+    The mandtory `--repository` option expects repositories to be configured in `~/.pypirc`.
     """
     run(f"twine upload --repository {repository} dist/*")
     run("git remote | xargs -L 1 -I remote git push remote")
