@@ -8,29 +8,45 @@ import os
 import configparser
 from invoke import run, task
 
-CONFIG_FILEPATH = "setup.cfg"
 FILE_TO_SEARCH_TEMPL = "bumpversion:file:{filepath}"
 
 
+def get_config_file():
+    """
+    Get config file
+
+    We want to use the .bumpversion file only if it is present, otherwise, we should use setup.cfg
+    """
+    package_default_path = ".bumpversion.cfg"
+    unified_config_path = "setup.cfg"
+    if os.path.exists(package_default_path):
+        return package_default_path
+    if os.path.exists(unified_config_path):
+        return unified_config_path
+    return None
+
+
 def init():
     config = configparser.ConfigParser()
+    config_filepath = get_config_file()
     
     config["bumpversion"] = dict(
         current_version="0.0.1",
         commit=True,
         tag=True)
     
-    config[FILE_TO_SEARCH_TEMPL.format(filepath=CONFIG_FILEPATH)] = dict()
+    config[FILE_TO_SEARCH_TEMPL.format(filepath=config_filepath)] = dict()
     
-    with open(CONFIG_FILEPATH, "w") as config_file:
+    with open(config_filepath, "w") as config_file:
         config.write(config_file)
 
 
 def bump(part: str):
+    config_filepath = get_config_file()
     cmd = "bumpversion{config_file} --allow-dirty {part}".format(
         # NOTE: Need this to convince bumpversion to work with setup.cfg it seems.
         # Has been observed at least in one case, but might not always be so.
-        config_file=" --config-file %s" % CONFIG_FILEPATH if os.path.exists(CONFIG_FILEPATH) else "",
+        config_file=" --config-file %s" % config_filepath if config_filepath else "",
         part=part)
     run(cmd, echo=True)
     push = input("\nPush version tags (y/n)? ")
@@ -42,9 +58,10 @@ def bump(part: str):
 
 def add_file(filepath: str):
     config = configparser.ConfigParser()
-    config.read(CONFIG_FILEPATH)
+    config_filepath = get_config_file()
+    config.read(config_filepath)
     config[FILE_TO_SEARCH_TEMPL.format(filepath=filepath)] = dict()
-    with open(CONFIG_FILEPATH, "w") as config_file:
+    with open(config_filepath, "w") as config_file:
         config.write(config_file)
 
 
